#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
import sys
import time
from subprocess import Popen, PIPE
from os.path import expanduser
import pexpect

home = expanduser("~")

def notify(message):
    os.system("terminal-notifier -sound default -title Cisco VPN '' -message " + message)


def disconnect():
    os.system("/opt/cisco/anyconnect/bin/vpn disconnect")


def connection(address, vpngroup, username, password):
    child = pexpect.spawn('/opt/cisco/anyconnect/bin/vpn connect ' + address, maxread=2000)
    child.logfile = sys.stdout
    child.expect('Group: \[.*\]')
    child.sendline(vpngroup)
    child.expect('Username: \[.*\]')
    child.sendline(username)
    child.expect('Password:')
    child.logfile = None
    child.sendline(password)
    child.logfile = sys.stdout
    child.expect('  >> notice: Establishing VPN session...')
    child.expect('  >> state: Connected')


def is_connect():
    global p, lines_nums, inline
    p = Popen(["/opt/cisco/anyconnect/bin/vpn", "state"], stdout=PIPE, close_fds=True)
    for lines_nums in xrange(1, 7):
        inline = p.stdout.readline()
        if "state: Connected" in inline:
            notify("Connected")
            return True
        elif "state: Disconnected" in inline:
            notify("Disconnected")
            return False


def read_config():
    text_file = open(home + "/.uap", "r")
    lines = text_file.read().split('\n')
    return lines


def main():
    while True:
        if not is_connect():
            configure = read_config()
            connection(configure[0], '1', configure[1], configure[2])

        time.sleep(30)


if __name__ == '__main__':
    main()


#!/usr/bin/env python

#!/usr/bin/env python
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os
import sys

if float("%d.%d" % sys.version_info[:2]) < 2.5 or float("%d.%d" % sys.version_info[:2]) >= 3.0:
    sys.stderr.write("Your Python version %d.%d.%d is not supported.\n" % sys.version_info[:3])
    sys.stderr.write("osscmd requires Python between 2.4 and 3.0.\n")
    sys.exit(1)

source_dir_list = []
package_list = []
data_file_dict = {}
data_file_list = []
for dir in os.listdir(os.getcwd()):
    if os.path.exists(os.path.join(dir, '__init__.py')):
        package_list.append(dir)
        source_dir_list.append(dir)

for source_dir in source_dir_list:
    for rootDir, dirs, files in os.walk(source_dir):
        for dir in dirs:
            dir = os.path.join(rootDir, dir)
            if os.path.exists(os.path.join(dir, '__init__.py')):
                package_list.append(dir.replace(os.sep, '.'))
        for file in files:
            file = os.path.join(rootDir, file)
            if not file.endswith('.py') and not file.endswith('.pyc') and '.svn' not in file:
                if rootDir not in data_file_dict.keys():
                    data_file_dict[rootDir] = [file]
                else:
                    data_file_dict[rootDir].append(file)

for k, v in data_file_dict.items():
    data_file_list.append((k, v))

setup(
    name = 'cisco_vpn',
    version = '0.0.5',
    keywords = ('cisco', 'vpn', 'cisco vpn'),
    description = 'Connect Cisco VPN With Python',
    license = 'MIT License',
    install_requires=[
            "docopt",
            "pexpect",
        ],

    url = 'http://www.phodal.com',
    author = 'Phodal Huang',
    author_email = 'h@phodal.com',

    packages=package_list,
    data_files=data_file_list,
    include_package_data = True,
    platforms = 'any',
    scripts=[
        'vpn',
    ],
)